from optparse import Option, OptionParser, _match_abbrev

#  Questo parser di opzioni insensibile a maiuscole/minuscole richiede 
#+ che sia disponibile un tipo di dizionario con la stessa caratteristica 
#+ nei confronti di maiuscole/minuscole. Questo  uno per il Python 2.2. 
#+ Notate che un dizionario reale insensibile a maiuscole/minuscole 
#+ richiede anche che siano implementati __new__(), update(), e 
#+ setdefault() -- ma non  questo l'oggetto di questo esercizio.

class caseless_dict (dict):
    def __setitem__ (self, key, value):
        dict.__setitem__(self, key.lower(), value)

    def __getitem__ (self, key):
        return dict.__getitem__(self, key.lower())

    def get (self, key, default=None):
        return dict.get(self, key.lower())

    def has_key (self, key):
        return dict.has_key(self, key.lower())


class CaselessOptionParser (OptionParser):

    def _create_option_list (self):
        self.option_list = []
        self._short_opt = caseless_dict()
        self._long_opt = caseless_dict()
        self._long_opts = []
        self.defaults = {}

    def _match_long_opt (self, opt):
        return _match_abbrev(opt.lower(), self._long_opt.keys())


if __name__ == "__main__":
    from optik.errors import OptionConflictError

    # test 1: nessuna opzione per partire con
    parser = CaselessOptionParser()
    try:
        parser.add_option("-H", dest="blah")
    except OptionConflictError:
        print "ok: ho OptionConflictError per -H"
    else:
        print "non  ok: nessuno conflitto tra  -h e -H"
    
    parser.add_option("-f", "--file", dest="file")
    #print repr(parser.get_option("-f"))
    #print repr(parser.get_option("-F"))
    #print repr(parser.get_option("--file"))
    #print repr(parser.get_option("--fIlE"))
    (options, args) = parser.parse_args(["--FiLe", "foo"])
    assert options.file == "foo", options.file
    print "ok: l'opzione lunga insensibile a maiuscole/minuscole lavora"

    (options, args) = parser.parse_args(["-F", "bar"])
    assert options.file == "bar", options.file
    print "ok: l'opzione lunga insensibile a maiuscole/minuscole lavora"
    
    
